@@ -1,11 +1,11 @@
 from lazyTest.base.base import WebOption
 from lazyTest.base.file import ReadYaml, ReadIni, ReadCsvFileToList
-from lazyTest.base.utils import Sleep, clearLogAndReport, createData, cls_Sleep
+from lazyTest.utils import Sleep, clearLogAndReport
 from lazyTest.case import TestCase
 from lazyTest.page import Page
 from lazyTest.model.elemetSource import ElementSource
-
-__version__ = '2.0.6'
+from lazyTest.base.lazy_log import logger
+__version__ = '2.0.7'
 
 __author__ = 'buxiubuzhi'
 
@@ -16,11 +16,10 @@ __all__ = [
     "Page",
     "clearLogAndReport",
     "WebOption",
-    "createData",
     "TestCase",
-    "cls_Sleep",
     "ReadYaml",
     "ReadIni",
     "ReadCsvFileToList",
-    "ElementSource"
+    "ElementSource",
+    "logger",
 ]
